Pillow
======

Pillow is the 'friendly' PIL fork by Alex Clark and Contributors. PIL is the Python Imaging Library by Fredrik Lundh and Contributors.

.. image:: https://travis-ci.org/python-pillow/Pillow.svg?branch=master
   :target: https://travis-ci.org/python-pillow/Pillow
   :alt: Travis CI build status

.. image:: https://pypip.in/v/Pillow/badge.png
    :target: https://pypi.python.org/pypi/Pillow/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/Pillow/badge.png
    :target: https://pypi.python.org/pypi/Pillow/
    :alt: Number of PyPI downloads

.. image:: https://coveralls.io/repos/python-pillow/Pillow/badge.png?branch=master
    :target: https://coveralls.io/r/python-pillow/Pillow?branch=master
    :alt: Test coverage

To install Pillow, please follow the :doc:`installation instructions <installation>`. To download source and/or contribute to development of Pillow please see: https://github.com/python-pillow/Pillow. 

.. toctree::
   :maxdepth: 2

   installation
   about
   guides
   reference/index.rst
   handbook/appendices
   releasenotes/index.rst
   original-readme

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
